# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/session_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grid.protos.grid.v1 import event_pb2 as grid_dot_v1_dot_event__pb2
from grid.protos.grid.v1 import session_pb2 as grid_dot_v1_dot_session__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/session_service.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dgrid/v1/session_service.proto\x12\x07grid.v1\x1a\x13grid/v1/event.proto\x1a\x15grid/v1/session.proto\"B\n\x14\x43reateSessionRequest\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session\"C\n\x15\x43reateSessionResponse\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session\"#\n\x11GetSessionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"@\n\x12GetSessionResponse\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session\"\xa2\x02\n\x13ListSessionsRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\x12\x19\n\x08user_ids\x18\x04 \x03(\tR\x07userIds\x12\x1d\n\ncluster_id\x18\x05 \x01(\tR\tclusterId\x12\x30\n\x08phase_in\x18\x06 \x03(\x0e\x32\x15.grid.v1.SessionStateR\x07phaseIn\x12\x37\n\x0cphase_not_in\x18\x07 \x03(\x0e\x32\x15.grid.v1.SessionStateR\nphaseNotIn\"\x94\x01\n\x14ListSessionsResponse\x12*\n\x07session\x18\x01 \x03(\x0b\x32\x10.grid.v1.SessionR\x07session\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"B\n\x14UpdateSessionRequest\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session\"C\n\x15UpdateSessionResponse\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session\"H\n\x1aUpdateSessionStatusRequest\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session\"I\n\x1bUpdateSessionStatusResponse\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session\"B\n\x14\x44\x65leteSessionRequest\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session\"C\n\x15\x44\x65leteSessionResponse\x12*\n\x07session\x18\x01 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session\"\xfc\x01\n\x14WatchSessionsRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12\x19\n\x08user_ids\x18\x04 \x03(\tR\x07userIds\x12\x1d\n\ncluster_id\x18\x05 \x01(\tR\tclusterId\x12\x30\n\x08phase_in\x18\x06 \x03(\x0e\x32\x15.grid.v1.SessionStateR\x07phaseIn\x12\x37\n\x0cphase_not_in\x18\x07 \x03(\x0e\x32\x15.grid.v1.SessionStateR\nphaseNotIn\"\x96\x01\n\x15WatchSessionsResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x12.grid.v1.EventTypeR\x04type\x12*\n\x07session\x18\x03 \x01(\x0b\x32\x10.grid.v1.SessionR\x07session2\xd2\x04\n\x0eSessionService\x12P\n\rCreateSession\x12\x1d.grid.v1.CreateSessionRequest\x1a\x1e.grid.v1.CreateSessionResponse\"\x00\x12G\n\nGetSession\x12\x1a.grid.v1.GetSessionRequest\x1a\x1b.grid.v1.GetSessionResponse\"\x00\x12M\n\x0cListSessions\x12\x1c.grid.v1.ListSessionsRequest\x1a\x1d.grid.v1.ListSessionsResponse\"\x00\x12P\n\rUpdateSession\x12\x1d.grid.v1.UpdateSessionRequest\x1a\x1e.grid.v1.UpdateSessionResponse\"\x00\x12`\n\x13UpdateSessionStatus\x12#.grid.v1.UpdateSessionStatusRequest\x1a$.grid.v1.UpdateSessionStatusResponse\x12P\n\rDeleteSession\x12\x1d.grid.v1.DeleteSessionRequest\x1a\x1e.grid.v1.DeleteSessionResponse\"\x00\x12P\n\rWatchSessions\x12\x1d.grid.v1.WatchSessionsRequest\x1a\x1e.grid.v1.WatchSessionsResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[grid_dot_v1_dot_event__pb2.DESCRIPTOR,grid_dot_v1_dot_session__pb2.DESCRIPTOR,])




_CREATESESSIONREQUEST = _descriptor.Descriptor(
  name='CreateSessionRequest',
  full_name='grid.v1.CreateSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='grid.v1.CreateSessionRequest.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='session', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=152,
)


_CREATESESSIONRESPONSE = _descriptor.Descriptor(
  name='CreateSessionResponse',
  full_name='grid.v1.CreateSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='grid.v1.CreateSessionResponse.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='session', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=154,
  serialized_end=221,
)


_GETSESSIONREQUEST = _descriptor.Descriptor(
  name='GetSessionRequest',
  full_name='grid.v1.GetSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grid.v1.GetSessionRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=223,
  serialized_end=258,
)


_GETSESSIONRESPONSE = _descriptor.Descriptor(
  name='GetSessionResponse',
  full_name='grid.v1.GetSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='grid.v1.GetSessionResponse.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='session', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=260,
  serialized_end=324,
)


_LISTSESSIONSREQUEST = _descriptor.Descriptor(
  name='ListSessionsRequest',
  full_name='grid.v1.ListSessionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListSessionsRequest.continue_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListSessionsRequest.resource_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.ListSessionsRequest.limit', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_ids', full_name='grid.v1.ListSessionsRequest.user_ids', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.ListSessionsRequest.cluster_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase_in', full_name='grid.v1.ListSessionsRequest.phase_in', index=5,
      number=6, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phaseIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase_not_in', full_name='grid.v1.ListSessionsRequest.phase_not_in', index=6,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phaseNotIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=617,
)


_LISTSESSIONSRESPONSE = _descriptor.Descriptor(
  name='ListSessionsResponse',
  full_name='grid.v1.ListSessionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='grid.v1.ListSessionsResponse.session', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='session', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListSessionsResponse.continue_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListSessionsResponse.resource_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=620,
  serialized_end=768,
)


_UPDATESESSIONREQUEST = _descriptor.Descriptor(
  name='UpdateSessionRequest',
  full_name='grid.v1.UpdateSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='grid.v1.UpdateSessionRequest.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='session', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=770,
  serialized_end=836,
)


_UPDATESESSIONRESPONSE = _descriptor.Descriptor(
  name='UpdateSessionResponse',
  full_name='grid.v1.UpdateSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='grid.v1.UpdateSessionResponse.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='session', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=838,
  serialized_end=905,
)


_UPDATESESSIONSTATUSREQUEST = _descriptor.Descriptor(
  name='UpdateSessionStatusRequest',
  full_name='grid.v1.UpdateSessionStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='grid.v1.UpdateSessionStatusRequest.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='session', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=907,
  serialized_end=979,
)


_UPDATESESSIONSTATUSRESPONSE = _descriptor.Descriptor(
  name='UpdateSessionStatusResponse',
  full_name='grid.v1.UpdateSessionStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='grid.v1.UpdateSessionStatusResponse.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='session', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=981,
  serialized_end=1054,
)


_DELETESESSIONREQUEST = _descriptor.Descriptor(
  name='DeleteSessionRequest',
  full_name='grid.v1.DeleteSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='grid.v1.DeleteSessionRequest.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='session', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1056,
  serialized_end=1122,
)


_DELETESESSIONRESPONSE = _descriptor.Descriptor(
  name='DeleteSessionResponse',
  full_name='grid.v1.DeleteSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='grid.v1.DeleteSessionResponse.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='session', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1124,
  serialized_end=1191,
)


_WATCHSESSIONSREQUEST = _descriptor.Descriptor(
  name='WatchSessionsRequest',
  full_name='grid.v1.WatchSessionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchSessionsRequest.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.WatchSessionsRequest.limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_ids', full_name='grid.v1.WatchSessionsRequest.user_ids', index=2,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.WatchSessionsRequest.cluster_id', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase_in', full_name='grid.v1.WatchSessionsRequest.phase_in', index=4,
      number=6, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phaseIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase_not_in', full_name='grid.v1.WatchSessionsRequest.phase_not_in', index=5,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phaseNotIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1194,
  serialized_end=1446,
)


_WATCHSESSIONSRESPONSE = _descriptor.Descriptor(
  name='WatchSessionsResponse',
  full_name='grid.v1.WatchSessionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchSessionsResponse.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='grid.v1.WatchSessionsResponse.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session', full_name='grid.v1.WatchSessionsResponse.session', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='session', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1449,
  serialized_end=1599,
)

_CREATESESSIONREQUEST.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_CREATESESSIONRESPONSE.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_GETSESSIONRESPONSE.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_LISTSESSIONSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_session__pb2._SESSIONSTATE
_LISTSESSIONSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_session__pb2._SESSIONSTATE
_LISTSESSIONSRESPONSE.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_UPDATESESSIONREQUEST.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_UPDATESESSIONRESPONSE.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_UPDATESESSIONSTATUSREQUEST.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_UPDATESESSIONSTATUSRESPONSE.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_DELETESESSIONREQUEST.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_DELETESESSIONRESPONSE.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
_WATCHSESSIONSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_session__pb2._SESSIONSTATE
_WATCHSESSIONSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_session__pb2._SESSIONSTATE
_WATCHSESSIONSRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_event__pb2._EVENTTYPE
_WATCHSESSIONSRESPONSE.fields_by_name['session'].message_type = grid_dot_v1_dot_session__pb2._SESSION
DESCRIPTOR.message_types_by_name['CreateSessionRequest'] = _CREATESESSIONREQUEST
DESCRIPTOR.message_types_by_name['CreateSessionResponse'] = _CREATESESSIONRESPONSE
DESCRIPTOR.message_types_by_name['GetSessionRequest'] = _GETSESSIONREQUEST
DESCRIPTOR.message_types_by_name['GetSessionResponse'] = _GETSESSIONRESPONSE
DESCRIPTOR.message_types_by_name['ListSessionsRequest'] = _LISTSESSIONSREQUEST
DESCRIPTOR.message_types_by_name['ListSessionsResponse'] = _LISTSESSIONSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateSessionRequest'] = _UPDATESESSIONREQUEST
DESCRIPTOR.message_types_by_name['UpdateSessionResponse'] = _UPDATESESSIONRESPONSE
DESCRIPTOR.message_types_by_name['UpdateSessionStatusRequest'] = _UPDATESESSIONSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateSessionStatusResponse'] = _UPDATESESSIONSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteSessionRequest'] = _DELETESESSIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteSessionResponse'] = _DELETESESSIONRESPONSE
DESCRIPTOR.message_types_by_name['WatchSessionsRequest'] = _WATCHSESSIONSREQUEST
DESCRIPTOR.message_types_by_name['WatchSessionsResponse'] = _WATCHSESSIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateSessionRequest = _reflection.GeneratedProtocolMessageType('CreateSessionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESESSIONREQUEST,
  '__module__' : 'grid.v1.session_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateSessionRequest)
  })
_sym_db.RegisterMessage(CreateSessionRequest)

CreateSessionResponse = _reflection.GeneratedProtocolMessageType('CreateSessionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESESSIONRESPONSE,
  '__module__' : 'grid.v1.session_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateSessionResponse)
  })
_sym_db.RegisterMessage(CreateSessionResponse)

GetSessionRequest = _reflection.GeneratedProtocolMessageType('GetSessionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSESSIONREQUEST,
  '__module__' : 'grid.v1.session_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetSessionRequest)
  })
_sym_db.RegisterMessage(GetSessionRequest)

GetSessionResponse = _reflection.GeneratedProtocolMessageType('GetSessionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSESSIONRESPONSE,
  '__module__' : 'grid.v1.session_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetSessionResponse)
  })
_sym_db.RegisterMessage(GetSessionResponse)

ListSessionsRequest = _reflection.GeneratedProtocolMessageType('ListSessionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSESSIONSREQUEST,
  '__module__' : 'grid.v1.session_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListSessionsRequest)
  })
_sym_db.RegisterMessage(ListSessionsRequest)

ListSessionsResponse = _reflection.GeneratedProtocolMessageType('ListSessionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSESSIONSRESPONSE,
  '__module__' : 'grid.v1.session_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListSessionsResponse)
  })
_sym_db.RegisterMessage(ListSessionsResponse)

UpdateSessionRequest = _reflection.GeneratedProtocolMessageType('UpdateSessionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESESSIONREQUEST,
  '__module__' : 'grid.v1.session_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateSessionRequest)
  })
_sym_db.RegisterMessage(UpdateSessionRequest)

UpdateSessionResponse = _reflection.GeneratedProtocolMessageType('UpdateSessionResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESESSIONRESPONSE,
  '__module__' : 'grid.v1.session_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateSessionResponse)
  })
_sym_db.RegisterMessage(UpdateSessionResponse)

UpdateSessionStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateSessionStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESESSIONSTATUSREQUEST,
  '__module__' : 'grid.v1.session_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateSessionStatusRequest)
  })
_sym_db.RegisterMessage(UpdateSessionStatusRequest)

UpdateSessionStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateSessionStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESESSIONSTATUSRESPONSE,
  '__module__' : 'grid.v1.session_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateSessionStatusResponse)
  })
_sym_db.RegisterMessage(UpdateSessionStatusResponse)

DeleteSessionRequest = _reflection.GeneratedProtocolMessageType('DeleteSessionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESESSIONREQUEST,
  '__module__' : 'grid.v1.session_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteSessionRequest)
  })
_sym_db.RegisterMessage(DeleteSessionRequest)

DeleteSessionResponse = _reflection.GeneratedProtocolMessageType('DeleteSessionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESESSIONRESPONSE,
  '__module__' : 'grid.v1.session_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteSessionResponse)
  })
_sym_db.RegisterMessage(DeleteSessionResponse)

WatchSessionsRequest = _reflection.GeneratedProtocolMessageType('WatchSessionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHSESSIONSREQUEST,
  '__module__' : 'grid.v1.session_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchSessionsRequest)
  })
_sym_db.RegisterMessage(WatchSessionsRequest)

WatchSessionsResponse = _reflection.GeneratedProtocolMessageType('WatchSessionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _WATCHSESSIONSRESPONSE,
  '__module__' : 'grid.v1.session_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchSessionsResponse)
  })
_sym_db.RegisterMessage(WatchSessionsResponse)


DESCRIPTOR._options = None

_SESSIONSERVICE = _descriptor.ServiceDescriptor(
  name='SessionService',
  full_name='grid.v1.SessionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1602,
  serialized_end=2196,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateSession',
    full_name='grid.v1.SessionService.CreateSession',
    index=0,
    containing_service=None,
    input_type=_CREATESESSIONREQUEST,
    output_type=_CREATESESSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSession',
    full_name='grid.v1.SessionService.GetSession',
    index=1,
    containing_service=None,
    input_type=_GETSESSIONREQUEST,
    output_type=_GETSESSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListSessions',
    full_name='grid.v1.SessionService.ListSessions',
    index=2,
    containing_service=None,
    input_type=_LISTSESSIONSREQUEST,
    output_type=_LISTSESSIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSession',
    full_name='grid.v1.SessionService.UpdateSession',
    index=3,
    containing_service=None,
    input_type=_UPDATESESSIONREQUEST,
    output_type=_UPDATESESSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSessionStatus',
    full_name='grid.v1.SessionService.UpdateSessionStatus',
    index=4,
    containing_service=None,
    input_type=_UPDATESESSIONSTATUSREQUEST,
    output_type=_UPDATESESSIONSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteSession',
    full_name='grid.v1.SessionService.DeleteSession',
    index=5,
    containing_service=None,
    input_type=_DELETESESSIONREQUEST,
    output_type=_DELETESESSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchSessions',
    full_name='grid.v1.SessionService.WatchSessions',
    index=6,
    containing_service=None,
    input_type=_WATCHSESSIONSREQUEST,
    output_type=_WATCHSESSIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SESSIONSERVICE)

DESCRIPTOR.services_by_name['SessionService'] = _SESSIONSERVICE

# @@protoc_insertion_point(module_scope)
