# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from grid.protos.grid.v1 import whoami_pb2 as grid_dot_v1_dot_whoami__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/event.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13grid/v1/event.proto\x12\x07grid.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a google/protobuf/descriptor.proto\x1a\x14grid/v1/whoami.proto\"\x9d\x03\n\x05\x45vent\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x1f\n\x0bresource_id\x18\x03 \x01(\tR\nresourceId\x12#\n\rresource_name\x18\x04 \x01(\tR\x0cresourceName\x12:\n\rresource_type\x18\x05 \x01(\x0e\x32\x15.grid.v1.ResourceTypeR\x0cresourceType\x12\x17\n\x07user_id\x18\x06 \x01(\tR\x06userId\x12\x1d\n\ncluster_id\x18\x07 \x01(\tR\tclusterId\x12\x31\n\nevent_type\x18\x08 \x01(\x0e\x32\x12.grid.v1.EventTypeR\teventType\x12/\n\x06\x63\x61ller\x18\t \x01(\x0b\x32\x17.grid.v1.WhoAmIResponseR\x06\x63\x61ller\x12,\n\x06object\x18\n \x01(\x0b\x32\x14.google.protobuf.AnyR\x06object*\xa7\x01\n\tEventType\x12+\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x1a\x0f\x8a\xb5\x18\x0bunspecified\x12#\n\x12\x45VENT_TYPE_CREATED\x10\x01\x1a\x0b\x8a\xb5\x18\x07\x63reated\x12#\n\x12\x45VENT_TYPE_UPDATED\x10\x02\x1a\x0b\x8a\xb5\x18\x07updated\x12#\n\x12\x45VENT_TYPE_DELETED\x10\x03\x1a\x0b\x8a\xb5\x18\x07\x64\x65leted*\x98\x02\n\x0cResourceType\x12.\n\x19RESOURCE_TYPE_UNSPECIFIED\x10\x00\x1a\x0f\x92\xb5\x18\x0bunspecified\x12,\n\x18RESOURCE_TYPE_EXPERIMENT\x10\x01\x1a\x0e\x92\xb5\x18\nexperiment\x12&\n\x15RESOURCE_TYPE_SESSION\x10\x02\x1a\x0b\x92\xb5\x18\x07session\x12*\n\x17RESOURCE_TYPE_DATASTORE\x10\x03\x1a\r\x92\xb5\x18\tdatastore\x12.\n\x19RESOURCE_TYPE_TENSORBOARD\x10\x04\x1a\x0f\x92\xb5\x18\x0btensorboard\x12&\n\x15RESOURCE_TYPE_CLUSTER\x10\x05\x1a\x0b\x92\xb5\x18\x07\x63luster:V\n\x15\x65vent_type_human_name\x12!.google.protobuf.EnumValueOptions\x18\xd1\x86\x03 \x01(\tR\x12\x65ventTypeHumanName:\\\n\x18resource_type_human_name\x12!.google.protobuf.EnumValueOptions\x18\xd2\x86\x03 \x01(\tR\x15resourceTypeHumanNameB2Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,grid_dot_v1_dot_whoami__pb2.DESCRIPTOR,])

_EVENTTYPE = _descriptor.EnumDescriptor(
  name='EventType',
  full_name='grid.v1.EventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EVENT_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=b'\212\265\030\013unspecified',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_TYPE_CREATED', index=1, number=1,
      serialized_options=b'\212\265\030\007created',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_TYPE_UPDATED', index=2, number=2,
      serialized_options=b'\212\265\030\007updated',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_TYPE_DELETED', index=3, number=3,
      serialized_options=b'\212\265\030\007deleted',
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=565,
  serialized_end=732,
)
_sym_db.RegisterEnumDescriptor(_EVENTTYPE)

EventType = enum_type_wrapper.EnumTypeWrapper(_EVENTTYPE)
_RESOURCETYPE = _descriptor.EnumDescriptor(
  name='ResourceType',
  full_name='grid.v1.ResourceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=b'\222\265\030\013unspecified',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_TYPE_EXPERIMENT', index=1, number=1,
      serialized_options=b'\222\265\030\nexperiment',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_TYPE_SESSION', index=2, number=2,
      serialized_options=b'\222\265\030\007session',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_TYPE_DATASTORE', index=3, number=3,
      serialized_options=b'\222\265\030\tdatastore',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_TYPE_TENSORBOARD', index=4, number=4,
      serialized_options=b'\222\265\030\013tensorboard',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_TYPE_CLUSTER', index=5, number=5,
      serialized_options=b'\222\265\030\007cluster',
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=735,
  serialized_end=1015,
)
_sym_db.RegisterEnumDescriptor(_RESOURCETYPE)

ResourceType = enum_type_wrapper.EnumTypeWrapper(_RESOURCETYPE)
EVENT_TYPE_UNSPECIFIED = 0
EVENT_TYPE_CREATED = 1
EVENT_TYPE_UPDATED = 2
EVENT_TYPE_DELETED = 3
RESOURCE_TYPE_UNSPECIFIED = 0
RESOURCE_TYPE_EXPERIMENT = 1
RESOURCE_TYPE_SESSION = 2
RESOURCE_TYPE_DATASTORE = 3
RESOURCE_TYPE_TENSORBOARD = 4
RESOURCE_TYPE_CLUSTER = 5

EVENT_TYPE_HUMAN_NAME_FIELD_NUMBER = 50001
event_type_human_name = _descriptor.FieldDescriptor(
  name='event_type_human_name', full_name='grid.v1.event_type_human_name', index=0,
  number=50001, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, json_name='eventTypeHumanName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
RESOURCE_TYPE_HUMAN_NAME_FIELD_NUMBER = 50002
resource_type_human_name = _descriptor.FieldDescriptor(
  name='resource_type_human_name', full_name='grid.v1.resource_type_human_name', index=1,
  number=50002, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, json_name='resourceTypeHumanName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)


_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='grid.v1.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grid.v1.Event.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='grid.v1.Event.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='grid.v1.Event.resource_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='grid.v1.Event.resource_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='grid.v1.Event.resource_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='grid.v1.Event.user_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.Event.cluster_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='grid.v1.Event.event_type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='eventType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='caller', full_name='grid.v1.Event.caller', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='caller', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object', full_name='grid.v1.Event.object', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='object', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=562,
)

_EVENT.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EVENT.fields_by_name['resource_type'].enum_type = _RESOURCETYPE
_EVENT.fields_by_name['event_type'].enum_type = _EVENTTYPE
_EVENT.fields_by_name['caller'].message_type = grid_dot_v1_dot_whoami__pb2._WHOAMIRESPONSE
_EVENT.fields_by_name['object'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
DESCRIPTOR.enum_types_by_name['EventType'] = _EVENTTYPE
DESCRIPTOR.enum_types_by_name['ResourceType'] = _RESOURCETYPE
DESCRIPTOR.extensions_by_name['event_type_human_name'] = event_type_human_name
DESCRIPTOR.extensions_by_name['resource_type_human_name'] = resource_type_human_name
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'grid.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.Event)
  })
_sym_db.RegisterMessage(Event)

google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(event_type_human_name)
google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(resource_type_human_name)

DESCRIPTOR._options = None
_EVENTTYPE.values_by_name["EVENT_TYPE_UNSPECIFIED"]._options = None
_EVENTTYPE.values_by_name["EVENT_TYPE_CREATED"]._options = None
_EVENTTYPE.values_by_name["EVENT_TYPE_UPDATED"]._options = None
_EVENTTYPE.values_by_name["EVENT_TYPE_DELETED"]._options = None
_RESOURCETYPE.values_by_name["RESOURCE_TYPE_UNSPECIFIED"]._options = None
_RESOURCETYPE.values_by_name["RESOURCE_TYPE_EXPERIMENT"]._options = None
_RESOURCETYPE.values_by_name["RESOURCE_TYPE_SESSION"]._options = None
_RESOURCETYPE.values_by_name["RESOURCE_TYPE_DATASTORE"]._options = None
_RESOURCETYPE.values_by_name["RESOURCE_TYPE_TENSORBOARD"]._options = None
_RESOURCETYPE.values_by_name["RESOURCE_TYPE_CLUSTER"]._options = None
# @@protoc_insertion_point(module_scope)
