# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/datastore.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/datastore.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17grid/v1/datastore.proto\x12\x07grid.v1\x1a\x16grid/v1/metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"\x98\x01\n\tDatastore\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x11.grid.v1.MetadataR\x08metadata\x12*\n\x04spec\x18\x02 \x01(\x0b\x32\x16.grid.v1.DatastoreSpecR\x04spec\x12\x30\n\x06status\x18\x03 \x01(\x0b\x32\x18.grid.v1.DatastoreStatusR\x06status\"\x80\x03\n\rDatastoreSpec\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x16\n\x04name\x18\x02 \x01(\tB\x02\x18\x01R\x04name\x12\x18\n\x07version\x18\x03 \x01(\rR\x07version\x12\x30\n\x06source\x18\x04 \x01(\x0b\x32\x18.grid.v1.DatastoreSourceR\x06source\x12<\n\rdesired_state\x18\x05 \x01(\x0e\x32\x17.grid.v1.DatastoreStateR\x0c\x64\x65siredState\x12;\n\x0buploaded_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nuploadedAt\x12\x1d\n\ncluster_id\x18\x07 \x01(\tR\tclusterId\x12\x19\n\x08size_mib\x18\x08 \x01(\rR\x07sizeMib\x12=\n\x0e\x64\x61tastore_type\x18\t \x01(\x0e\x32\x16.grid.v1.DatastoreTypeR\rdatastoreType\"/\n\x0f\x44\x61tastoreSource\x12\x12\n\x03\x64sn\x18\x01 \x01(\tH\x00R\x03\x64snB\x08\n\x06source\"\xf3\x01\n\x0f\x44\x61tastoreStatus\x12:\n\x05phase\x18\x01 \x01(\x0e\x32$.grid.v1.DatastoreOptimizationStatusR\x05phase\x12\x1d\n\nsize_bytes\x18\x02 \x01(\x04R\tsizeBytes\x12=\n\x0bsnapshot_id\x18\x03 \x01(\x0b\x32\x1c.grid.v1.DatastoreSnapshotIDR\nsnapshotId\x12#\n\rextracted_url\x18\x04 \x01(\tR\x0c\x65xtractedUrl\x12!\n\x0cmetadata_url\x18\x05 \x01(\tR\x0bmetadataUrl\"\x8a\x01\n\x13\x44\x61tastoreSnapshotID\x12\x32\n\x08\x65xternal\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00R\x08\x65xternal\x12\x39\n\x18k8s_volume_snapshot_name\x18\x02 \x01(\tH\x00R\x15k8sVolumeSnapshotNameB\x04\n\x02id\"A\n\x0e\x44\x61tastoreInput\x12\x10\n\x03\x64sn\x18\x01 \x01(\tR\x03\x64sn\x12\x1d\n\nmount_path\x18\x02 \x01(\tR\tmountPath*p\n\rDatastoreType\x12\x1e\n\x1a\x44\x41TASTORE_TYPE_UNSPECIFIED\x10\x00\x12$\n DATASTORE_TYPE_COMPRESSED_SOURCE\x10\x01\x12\x19\n\x15\x44\x41TASTORE_TYPE_FOLDER\x10\x02*\x8a\x01\n\x0e\x44\x61tastoreState\x12\x1f\n\x1b\x44\x41TASTORE_STATE_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x44\x41TASTORE_STATE_UPLOADING\x10\x01\x12\x1b\n\x17\x44\x41TASTORE_STATE_CREATED\x10\x02\x12\x1b\n\x17\x44\x41TASTORE_STATE_DELETED\x10\x03*\xab\x02\n\x1b\x44\x61tastoreOptimizationStatus\x12-\n)DATASTORE_OPTIMIZATION_STATUS_UNSPECIFIED\x10\x00\x12+\n\'DATASTORE_OPTIMIZATION_STATUS_SUCCEEDED\x10\x01\x12(\n$DATASTORE_OPTIMIZATION_STATUS_FAILED\x10\x02\x12,\n(DATASTORE_OPTIMIZATION_STATUS_OPTIMIZING\x10\x03\x12)\n%DATASTORE_OPTIMIZATION_STATUS_DELETED\x10\x04\x12-\n)DATASTORE_OPTIMIZATION_STATUS_POD_PENDING\x10\x05\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])

_DATASTORETYPE = _descriptor.EnumDescriptor(
  name='DatastoreType',
  full_name='grid.v1.DatastoreType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DATASTORE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATASTORE_TYPE_COMPRESSED_SOURCE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATASTORE_TYPE_FOLDER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1165,
  serialized_end=1277,
)
_sym_db.RegisterEnumDescriptor(_DATASTORETYPE)

DatastoreType = enum_type_wrapper.EnumTypeWrapper(_DATASTORETYPE)
_DATASTORESTATE = _descriptor.EnumDescriptor(
  name='DatastoreState',
  full_name='grid.v1.DatastoreState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DATASTORE_STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATASTORE_STATE_UPLOADING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATASTORE_STATE_CREATED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATASTORE_STATE_DELETED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1280,
  serialized_end=1418,
)
_sym_db.RegisterEnumDescriptor(_DATASTORESTATE)

DatastoreState = enum_type_wrapper.EnumTypeWrapper(_DATASTORESTATE)
_DATASTOREOPTIMIZATIONSTATUS = _descriptor.EnumDescriptor(
  name='DatastoreOptimizationStatus',
  full_name='grid.v1.DatastoreOptimizationStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DATASTORE_OPTIMIZATION_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATASTORE_OPTIMIZATION_STATUS_SUCCEEDED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATASTORE_OPTIMIZATION_STATUS_FAILED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATASTORE_OPTIMIZATION_STATUS_OPTIMIZING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATASTORE_OPTIMIZATION_STATUS_DELETED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATASTORE_OPTIMIZATION_STATUS_POD_PENDING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1421,
  serialized_end=1720,
)
_sym_db.RegisterEnumDescriptor(_DATASTOREOPTIMIZATIONSTATUS)

DatastoreOptimizationStatus = enum_type_wrapper.EnumTypeWrapper(_DATASTOREOPTIMIZATIONSTATUS)
DATASTORE_TYPE_UNSPECIFIED = 0
DATASTORE_TYPE_COMPRESSED_SOURCE = 1
DATASTORE_TYPE_FOLDER = 2
DATASTORE_STATE_UNSPECIFIED = 0
DATASTORE_STATE_UPLOADING = 1
DATASTORE_STATE_CREATED = 2
DATASTORE_STATE_DELETED = 3
DATASTORE_OPTIMIZATION_STATUS_UNSPECIFIED = 0
DATASTORE_OPTIMIZATION_STATUS_SUCCEEDED = 1
DATASTORE_OPTIMIZATION_STATUS_FAILED = 2
DATASTORE_OPTIMIZATION_STATUS_OPTIMIZING = 3
DATASTORE_OPTIMIZATION_STATUS_DELETED = 4
DATASTORE_OPTIMIZATION_STATUS_POD_PENDING = 5



_DATASTORE = _descriptor.Descriptor(
  name='Datastore',
  full_name='grid.v1.Datastore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='grid.v1.Datastore.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metadata', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='grid.v1.Datastore.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='spec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='grid.v1.Datastore.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=273,
)


_DATASTORESPEC = _descriptor.Descriptor(
  name='DatastoreSpec',
  full_name='grid.v1.DatastoreSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='grid.v1.DatastoreSpec.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='grid.v1.DatastoreSpec.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='grid.v1.DatastoreSpec.version', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='version', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='grid.v1.DatastoreSpec.source', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='source', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desired_state', full_name='grid.v1.DatastoreSpec.desired_state', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='desiredState', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uploaded_at', full_name='grid.v1.DatastoreSpec.uploaded_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='uploadedAt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.DatastoreSpec.cluster_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size_mib', full_name='grid.v1.DatastoreSpec.size_mib', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sizeMib', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datastore_type', full_name='grid.v1.DatastoreSpec.datastore_type', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='datastoreType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=660,
)


_DATASTORESOURCE = _descriptor.Descriptor(
  name='DatastoreSource',
  full_name='grid.v1.DatastoreSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsn', full_name='grid.v1.DatastoreSource.dsn', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dsn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source', full_name='grid.v1.DatastoreSource.source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=662,
  serialized_end=709,
)


_DATASTORESTATUS = _descriptor.Descriptor(
  name='DatastoreStatus',
  full_name='grid.v1.DatastoreStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='phase', full_name='grid.v1.DatastoreStatus.phase', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phase', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size_bytes', full_name='grid.v1.DatastoreStatus.size_bytes', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sizeBytes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot_id', full_name='grid.v1.DatastoreStatus.snapshot_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='snapshotId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extracted_url', full_name='grid.v1.DatastoreStatus.extracted_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='extractedUrl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_url', full_name='grid.v1.DatastoreStatus.metadata_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metadataUrl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=712,
  serialized_end=955,
)


_DATASTORESNAPSHOTID = _descriptor.Descriptor(
  name='DatastoreSnapshotID',
  full_name='grid.v1.DatastoreSnapshotID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='external', full_name='grid.v1.DatastoreSnapshotID.external', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='external', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='k8s_volume_snapshot_name', full_name='grid.v1.DatastoreSnapshotID.k8s_volume_snapshot_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='k8sVolumeSnapshotName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='id', full_name='grid.v1.DatastoreSnapshotID.id',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=958,
  serialized_end=1096,
)


_DATASTOREINPUT = _descriptor.Descriptor(
  name='DatastoreInput',
  full_name='grid.v1.DatastoreInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsn', full_name='grid.v1.DatastoreInput.dsn', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dsn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mount_path', full_name='grid.v1.DatastoreInput.mount_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='mountPath', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1098,
  serialized_end=1163,
)

_DATASTORE.fields_by_name['metadata'].message_type = grid_dot_v1_dot_metadata__pb2._METADATA
_DATASTORE.fields_by_name['spec'].message_type = _DATASTORESPEC
_DATASTORE.fields_by_name['status'].message_type = _DATASTORESTATUS
_DATASTORESPEC.fields_by_name['source'].message_type = _DATASTORESOURCE
_DATASTORESPEC.fields_by_name['desired_state'].enum_type = _DATASTORESTATE
_DATASTORESPEC.fields_by_name['uploaded_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DATASTORESPEC.fields_by_name['datastore_type'].enum_type = _DATASTORETYPE
_DATASTORESOURCE.oneofs_by_name['source'].fields.append(
  _DATASTORESOURCE.fields_by_name['dsn'])
_DATASTORESOURCE.fields_by_name['dsn'].containing_oneof = _DATASTORESOURCE.oneofs_by_name['source']
_DATASTORESTATUS.fields_by_name['phase'].enum_type = _DATASTOREOPTIMIZATIONSTATUS
_DATASTORESTATUS.fields_by_name['snapshot_id'].message_type = _DATASTORESNAPSHOTID
_DATASTORESNAPSHOTID.fields_by_name['external'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_DATASTORESNAPSHOTID.oneofs_by_name['id'].fields.append(
  _DATASTORESNAPSHOTID.fields_by_name['external'])
_DATASTORESNAPSHOTID.fields_by_name['external'].containing_oneof = _DATASTORESNAPSHOTID.oneofs_by_name['id']
_DATASTORESNAPSHOTID.oneofs_by_name['id'].fields.append(
  _DATASTORESNAPSHOTID.fields_by_name['k8s_volume_snapshot_name'])
_DATASTORESNAPSHOTID.fields_by_name['k8s_volume_snapshot_name'].containing_oneof = _DATASTORESNAPSHOTID.oneofs_by_name['id']
DESCRIPTOR.message_types_by_name['Datastore'] = _DATASTORE
DESCRIPTOR.message_types_by_name['DatastoreSpec'] = _DATASTORESPEC
DESCRIPTOR.message_types_by_name['DatastoreSource'] = _DATASTORESOURCE
DESCRIPTOR.message_types_by_name['DatastoreStatus'] = _DATASTORESTATUS
DESCRIPTOR.message_types_by_name['DatastoreSnapshotID'] = _DATASTORESNAPSHOTID
DESCRIPTOR.message_types_by_name['DatastoreInput'] = _DATASTOREINPUT
DESCRIPTOR.enum_types_by_name['DatastoreType'] = _DATASTORETYPE
DESCRIPTOR.enum_types_by_name['DatastoreState'] = _DATASTORESTATE
DESCRIPTOR.enum_types_by_name['DatastoreOptimizationStatus'] = _DATASTOREOPTIMIZATIONSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Datastore = _reflection.GeneratedProtocolMessageType('Datastore', (_message.Message,), {
  'DESCRIPTOR' : _DATASTORE,
  '__module__' : 'grid.v1.datastore_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.Datastore)
  })
_sym_db.RegisterMessage(Datastore)

DatastoreSpec = _reflection.GeneratedProtocolMessageType('DatastoreSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATASTORESPEC,
  '__module__' : 'grid.v1.datastore_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DatastoreSpec)
  })
_sym_db.RegisterMessage(DatastoreSpec)

DatastoreSource = _reflection.GeneratedProtocolMessageType('DatastoreSource', (_message.Message,), {
  'DESCRIPTOR' : _DATASTORESOURCE,
  '__module__' : 'grid.v1.datastore_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DatastoreSource)
  })
_sym_db.RegisterMessage(DatastoreSource)

DatastoreStatus = _reflection.GeneratedProtocolMessageType('DatastoreStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATASTORESTATUS,
  '__module__' : 'grid.v1.datastore_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DatastoreStatus)
  })
_sym_db.RegisterMessage(DatastoreStatus)

DatastoreSnapshotID = _reflection.GeneratedProtocolMessageType('DatastoreSnapshotID', (_message.Message,), {
  'DESCRIPTOR' : _DATASTORESNAPSHOTID,
  '__module__' : 'grid.v1.datastore_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DatastoreSnapshotID)
  })
_sym_db.RegisterMessage(DatastoreSnapshotID)

DatastoreInput = _reflection.GeneratedProtocolMessageType('DatastoreInput', (_message.Message,), {
  'DESCRIPTOR' : _DATASTOREINPUT,
  '__module__' : 'grid.v1.datastore_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DatastoreInput)
  })
_sym_db.RegisterMessage(DatastoreInput)


DESCRIPTOR._options = None
_DATASTORESPEC.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)
