# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/session.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from grid.protos.grid.v1 import datastore_pb2 as grid_dot_v1_dot_datastore__pb2
from grid.protos.grid.v1 import resource_pb2 as grid_dot_v1_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/session.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15grid/v1/session.proto\x12\x07grid.v1\x1a\x16grid/v1/metadata.proto\x1a\x17grid/v1/datastore.proto\x1a\x16grid/v1/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1fgoogle/api/field_behavior.proto\"\x92\x01\n\x07Session\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x11.grid.v1.MetadataR\x08metadata\x12(\n\x04spec\x18\x02 \x01(\x0b\x32\x14.grid.v1.SessionSpecR\x04spec\x12.\n\x06status\x18\x03 \x01(\x0b\x32\x16.grid.v1.SessionStatusR\x06status\"\xe3\x02\n\x0bSessionSpec\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x1d\n\x07user_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x05R\x06userId\x12:\n\rdesired_state\x18\x03 \x01(\x0e\x32\x15.grid.v1.SessionStateR\x0c\x64\x65siredState\x12#\n\rinstance_type\x18\x04 \x01(\tR\x0cinstanceType\x12\x30\n\tresources\x18\x05 \x01(\x0b\x32\x12.grid.v1.ResourcesR\tresources\x12\x37\n\ndatastores\x18\x06 \x03(\x0b\x32\x17.grid.v1.DatastoreInputR\ndatastores\x12/\n\x10pause_automation\x18\x07 \x01(\x08\x42\x04\xe2\x41\x01\x03R\x0fpauseAutomation\x12\x19\n\x08use_spot\x18\x08 \x01(\x08R\x07useSpot\"\xa3\x04\n\rSessionStatus\x12+\n\x05phase\x18\x01 \x01(\x0e\x32\x15.grid.v1.SessionStateR\x05phase\x12\x17\n\x07ssh_url\x18\x02 \x01(\tR\x06sshUrl\x12&\n\x0fjupyter_lab_url\x18\x03 \x01(\tR\rjupyterLabUrl\x12\x33\n\x16total_run_time_seconds\x18\x04 \x01(\x04R\x13totalRunTimeSeconds\x12\x43\n\x0fstart_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0estartTimestamp\x12\x41\n\x0estop_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rstopTimestamp\x12K\n\x13\x64\x65stroyed_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x12\x64\x65stroyedTimestamp\x12n\n&last_state_status_transition_timestamp\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\"lastStateStatusTransitionTimestamp\x12*\n\x11jupyter_lab_token\x18\t \x01(\tR\x0fjupyterLabToken*\x98\x01\n\x0cSessionState\x12\x1d\n\x19SESSION_STATE_UNSPECIFIED\x10\x00\x12\x19\n\x15SESSION_STATE_PENDING\x10\x01\x12\x19\n\x15SESSION_STATE_RUNNING\x10\x02\x12\x18\n\x14SESSION_STATE_PAUSED\x10\x03\x12\x19\n\x15SESSION_STATE_DELETED\x10\x04\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,grid_dot_v1_dot_datastore__pb2.DESCRIPTOR,grid_dot_v1_dot_resource__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,])

_SESSIONSTATE = _descriptor.EnumDescriptor(
  name='SessionState',
  full_name='grid.v1.SessionState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SESSION_STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SESSION_STATE_PENDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SESSION_STATE_RUNNING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SESSION_STATE_PAUSED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SESSION_STATE_DELETED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1231,
  serialized_end=1383,
)
_sym_db.RegisterEnumDescriptor(_SESSIONSTATE)

SessionState = enum_type_wrapper.EnumTypeWrapper(_SESSIONSTATE)
SESSION_STATE_UNSPECIFIED = 0
SESSION_STATE_PENDING = 1
SESSION_STATE_RUNNING = 2
SESSION_STATE_PAUSED = 3
SESSION_STATE_DELETED = 4



_SESSION = _descriptor.Descriptor(
  name='Session',
  full_name='grid.v1.Session',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='grid.v1.Session.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metadata', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='grid.v1.Session.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='spec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='grid.v1.Session.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=320,
)


_SESSIONSPEC = _descriptor.Descriptor(
  name='SessionSpec',
  full_name='grid.v1.SessionSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.SessionSpec.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='grid.v1.SessionSpec.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\005', json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desired_state', full_name='grid.v1.SessionSpec.desired_state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='desiredState', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_type', full_name='grid.v1.SessionSpec.instance_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='instanceType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='grid.v1.SessionSpec.resources', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resources', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datastores', full_name='grid.v1.SessionSpec.datastores', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='datastores', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pause_automation', full_name='grid.v1.SessionSpec.pause_automation', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='pauseAutomation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_spot', full_name='grid.v1.SessionSpec.use_spot', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='useSpot', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=323,
  serialized_end=678,
)


_SESSIONSTATUS = _descriptor.Descriptor(
  name='SessionStatus',
  full_name='grid.v1.SessionStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='phase', full_name='grid.v1.SessionStatus.phase', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phase', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssh_url', full_name='grid.v1.SessionStatus.ssh_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshUrl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jupyter_lab_url', full_name='grid.v1.SessionStatus.jupyter_lab_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jupyterLabUrl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_run_time_seconds', full_name='grid.v1.SessionStatus.total_run_time_seconds', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='totalRunTimeSeconds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='grid.v1.SessionStatus.start_timestamp', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='startTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_timestamp', full_name='grid.v1.SessionStatus.stop_timestamp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='stopTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destroyed_timestamp', full_name='grid.v1.SessionStatus.destroyed_timestamp', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='destroyedTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_state_status_transition_timestamp', full_name='grid.v1.SessionStatus.last_state_status_transition_timestamp', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='lastStateStatusTransitionTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jupyter_lab_token', full_name='grid.v1.SessionStatus.jupyter_lab_token', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jupyterLabToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=681,
  serialized_end=1228,
)

_SESSION.fields_by_name['metadata'].message_type = grid_dot_v1_dot_metadata__pb2._METADATA
_SESSION.fields_by_name['spec'].message_type = _SESSIONSPEC
_SESSION.fields_by_name['status'].message_type = _SESSIONSTATUS
_SESSIONSPEC.fields_by_name['desired_state'].enum_type = _SESSIONSTATE
_SESSIONSPEC.fields_by_name['resources'].message_type = grid_dot_v1_dot_resource__pb2._RESOURCES
_SESSIONSPEC.fields_by_name['datastores'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTOREINPUT
_SESSIONSTATUS.fields_by_name['phase'].enum_type = _SESSIONSTATE
_SESSIONSTATUS.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SESSIONSTATUS.fields_by_name['stop_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SESSIONSTATUS.fields_by_name['destroyed_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SESSIONSTATUS.fields_by_name['last_state_status_transition_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Session'] = _SESSION
DESCRIPTOR.message_types_by_name['SessionSpec'] = _SESSIONSPEC
DESCRIPTOR.message_types_by_name['SessionStatus'] = _SESSIONSTATUS
DESCRIPTOR.enum_types_by_name['SessionState'] = _SESSIONSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Session = _reflection.GeneratedProtocolMessageType('Session', (_message.Message,), {
  'DESCRIPTOR' : _SESSION,
  '__module__' : 'grid.v1.session_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.Session)
  })
_sym_db.RegisterMessage(Session)

SessionSpec = _reflection.GeneratedProtocolMessageType('SessionSpec', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONSPEC,
  '__module__' : 'grid.v1.session_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.SessionSpec)
  })
_sym_db.RegisterMessage(SessionSpec)

SessionStatus = _reflection.GeneratedProtocolMessageType('SessionStatus', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONSTATUS,
  '__module__' : 'grid.v1.session_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.SessionStatus)
  })
_sym_db.RegisterMessage(SessionStatus)


DESCRIPTOR._options = None
_SESSIONSPEC.fields_by_name['user_id']._options = None
_SESSIONSPEC.fields_by_name['pause_automation']._options = None
# @@protoc_insertion_point(module_scope)
