# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import auth_service_pb2 as grid_dot_v1_dot_auth__service__pb2


class AuthServiceStub(object):
    # missing associated documentation comment in .proto file
    pass

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.Login = channel.unary_unary(
            '/grid.v1.AuthService/Login',
            request_serializer=grid_dot_v1_dot_auth__service__pb2.LoginRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_auth__service__pb2.LoginResponse.FromString,
        )
        self.Refresh = channel.unary_unary(
            '/grid.v1.AuthService/Refresh',
            request_serializer=grid_dot_v1_dot_auth__service__pb2.RefreshRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_auth__service__pb2.RefreshResponse.FromString,
        )
        self.Logout = channel.unary_unary(
            '/grid.v1.AuthService/Logout',
            request_serializer=grid_dot_v1_dot_auth__service__pb2.LogoutRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_auth__service__pb2.LogoutResponse.FromString,
        )


class AuthServiceServicer(object):
    # missing associated documentation comment in .proto file
    pass

    def Login(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Refresh(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Logout(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'Login':
        grpc.unary_unary_rpc_method_handler(
            servicer.Login,
            request_deserializer=grid_dot_v1_dot_auth__service__pb2.LoginRequest.FromString,
            response_serializer=grid_dot_v1_dot_auth__service__pb2.LoginResponse.SerializeToString,
        ),
        'Refresh':
        grpc.unary_unary_rpc_method_handler(
            servicer.Refresh,
            request_deserializer=grid_dot_v1_dot_auth__service__pb2.RefreshRequest.FromString,
            response_serializer=grid_dot_v1_dot_auth__service__pb2.RefreshResponse.SerializeToString,
        ),
        'Logout':
        grpc.unary_unary_rpc_method_handler(
            servicer.Logout,
            request_deserializer=grid_dot_v1_dot_auth__service__pb2.LogoutRequest.FromString,
            response_serializer=grid_dot_v1_dot_auth__service__pb2.LogoutResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler('grid.v1.AuthService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler, ))
