# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/datastore_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grid.protos.grid.v1 import event_pb2 as grid_dot_v1_dot_event__pb2
from grid.protos.grid.v1 import datastore_pb2 as grid_dot_v1_dot_datastore__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/datastore_service.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fgrid/v1/datastore_service.proto\x12\x07grid.v1\x1a\x13grid/v1/event.proto\x1a\x17grid/v1/datastore.proto\"J\n\x16\x43reateDatastoreRequest\x12\x30\n\tdatastore\x18\x01 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\"K\n\x17\x43reateDatastoreResponse\x12\x30\n\tdatastore\x18\x01 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\"%\n\x13GetDatastoreRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"H\n\x14GetDatastoreResponse\x12\x30\n\tdatastore\x18\x01 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\"\xd7\x01\n\x15ListDatastoresRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\x12\x19\n\x08user_ids\x18\x04 \x03(\tR\x07userIds\x12\x1c\n\tavailable\x18\x05 \x01(\x08R\tavailable\x12\x1d\n\ncluster_id\x18\x06 \x01(\tR\tclusterId\"\x9c\x01\n\x16ListDatastoresResponse\x12\x30\n\tdatastore\x18\x01 \x03(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"J\n\x16UpdateDatastoreRequest\x12\x30\n\tdatastore\x18\x01 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\"K\n\x17UpdateDatastoreResponse\x12\x30\n\tdatastore\x18\x01 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\"P\n\x1cUpdateDatastoreStatusRequest\x12\x30\n\tdatastore\x18\x01 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\"Q\n\x1dUpdateDatastoreStatusResponse\x12\x30\n\tdatastore\x18\x01 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\"J\n\x16\x44\x65leteDatastoreRequest\x12\x30\n\tdatastore\x18\x01 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\"K\n\x17\x44\x65leteDatastoreResponse\x12\x30\n\tdatastore\x18\x01 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore\"\xb1\x01\n\x16WatchDatastoresRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12\x19\n\x08user_ids\x18\x04 \x03(\tR\x07userIds\x12\x1c\n\tavailable\x18\x05 \x01(\x08R\tavailable\x12\x1d\n\ncluster_id\x18\x06 \x01(\tR\tclusterId\"\x9e\x01\n\x17WatchDatastoresResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x12.grid.v1.EventTypeR\x04type\x12\x30\n\tdatastore\x18\x03 \x01(\x0b\x32\x12.grid.v1.DatastoreR\tdatastore2\xfe\x04\n\x10\x44\x61tastoreService\x12V\n\x0f\x43reateDatastore\x12\x1f.grid.v1.CreateDatastoreRequest\x1a .grid.v1.CreateDatastoreResponse\"\x00\x12M\n\x0cGetDatastore\x12\x1c.grid.v1.GetDatastoreRequest\x1a\x1d.grid.v1.GetDatastoreResponse\"\x00\x12S\n\x0eListDatastores\x12\x1e.grid.v1.ListDatastoresRequest\x1a\x1f.grid.v1.ListDatastoresResponse\"\x00\x12V\n\x0fUpdateDatastore\x12\x1f.grid.v1.UpdateDatastoreRequest\x1a .grid.v1.UpdateDatastoreResponse\"\x00\x12\x66\n\x15UpdateDatastoreStatus\x12%.grid.v1.UpdateDatastoreStatusRequest\x1a&.grid.v1.UpdateDatastoreStatusResponse\x12V\n\x0f\x44\x65leteDatastore\x12\x1f.grid.v1.DeleteDatastoreRequest\x1a .grid.v1.DeleteDatastoreResponse\"\x00\x12V\n\x0fWatchDatastores\x12\x1f.grid.v1.WatchDatastoresRequest\x1a .grid.v1.WatchDatastoresResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[grid_dot_v1_dot_event__pb2.DESCRIPTOR,grid_dot_v1_dot_datastore__pb2.DESCRIPTOR,])




_CREATEDATASTOREREQUEST = _descriptor.Descriptor(
  name='CreateDatastoreRequest',
  full_name='grid.v1.CreateDatastoreRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='datastore', full_name='grid.v1.CreateDatastoreRequest.datastore', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='datastore', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=164,
)


_CREATEDATASTORERESPONSE = _descriptor.Descriptor(
  name='CreateDatastoreResponse',
  full_name='grid.v1.CreateDatastoreResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='datastore', full_name='grid.v1.CreateDatastoreResponse.datastore', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='datastore', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=241,
)


_GETDATASTOREREQUEST = _descriptor.Descriptor(
  name='GetDatastoreRequest',
  full_name='grid.v1.GetDatastoreRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grid.v1.GetDatastoreRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=280,
)


_GETDATASTORERESPONSE = _descriptor.Descriptor(
  name='GetDatastoreResponse',
  full_name='grid.v1.GetDatastoreResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='datastore', full_name='grid.v1.GetDatastoreResponse.datastore', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='datastore', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=282,
  serialized_end=354,
)


_LISTDATASTORESREQUEST = _descriptor.Descriptor(
  name='ListDatastoresRequest',
  full_name='grid.v1.ListDatastoresRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListDatastoresRequest.continue_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListDatastoresRequest.resource_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.ListDatastoresRequest.limit', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_ids', full_name='grid.v1.ListDatastoresRequest.user_ids', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available', full_name='grid.v1.ListDatastoresRequest.available', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='available', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.ListDatastoresRequest.cluster_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=572,
)


_LISTDATASTORESRESPONSE = _descriptor.Descriptor(
  name='ListDatastoresResponse',
  full_name='grid.v1.ListDatastoresResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='datastore', full_name='grid.v1.ListDatastoresResponse.datastore', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='datastore', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListDatastoresResponse.continue_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListDatastoresResponse.resource_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=731,
)


_UPDATEDATASTOREREQUEST = _descriptor.Descriptor(
  name='UpdateDatastoreRequest',
  full_name='grid.v1.UpdateDatastoreRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='datastore', full_name='grid.v1.UpdateDatastoreRequest.datastore', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='datastore', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=733,
  serialized_end=807,
)


_UPDATEDATASTORERESPONSE = _descriptor.Descriptor(
  name='UpdateDatastoreResponse',
  full_name='grid.v1.UpdateDatastoreResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='datastore', full_name='grid.v1.UpdateDatastoreResponse.datastore', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='datastore', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=809,
  serialized_end=884,
)


_UPDATEDATASTORESTATUSREQUEST = _descriptor.Descriptor(
  name='UpdateDatastoreStatusRequest',
  full_name='grid.v1.UpdateDatastoreStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='datastore', full_name='grid.v1.UpdateDatastoreStatusRequest.datastore', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='datastore', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=886,
  serialized_end=966,
)


_UPDATEDATASTORESTATUSRESPONSE = _descriptor.Descriptor(
  name='UpdateDatastoreStatusResponse',
  full_name='grid.v1.UpdateDatastoreStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='datastore', full_name='grid.v1.UpdateDatastoreStatusResponse.datastore', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='datastore', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=968,
  serialized_end=1049,
)


_DELETEDATASTOREREQUEST = _descriptor.Descriptor(
  name='DeleteDatastoreRequest',
  full_name='grid.v1.DeleteDatastoreRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='datastore', full_name='grid.v1.DeleteDatastoreRequest.datastore', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='datastore', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1051,
  serialized_end=1125,
)


_DELETEDATASTORERESPONSE = _descriptor.Descriptor(
  name='DeleteDatastoreResponse',
  full_name='grid.v1.DeleteDatastoreResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='datastore', full_name='grid.v1.DeleteDatastoreResponse.datastore', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='datastore', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1127,
  serialized_end=1202,
)


_WATCHDATASTORESREQUEST = _descriptor.Descriptor(
  name='WatchDatastoresRequest',
  full_name='grid.v1.WatchDatastoresRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchDatastoresRequest.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.WatchDatastoresRequest.limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_ids', full_name='grid.v1.WatchDatastoresRequest.user_ids', index=2,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available', full_name='grid.v1.WatchDatastoresRequest.available', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='available', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.WatchDatastoresRequest.cluster_id', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1205,
  serialized_end=1382,
)


_WATCHDATASTORESRESPONSE = _descriptor.Descriptor(
  name='WatchDatastoresResponse',
  full_name='grid.v1.WatchDatastoresResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchDatastoresResponse.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='grid.v1.WatchDatastoresResponse.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datastore', full_name='grid.v1.WatchDatastoresResponse.datastore', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='datastore', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1385,
  serialized_end=1543,
)

_CREATEDATASTOREREQUEST.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_CREATEDATASTORERESPONSE.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_GETDATASTORERESPONSE.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_LISTDATASTORESRESPONSE.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_UPDATEDATASTOREREQUEST.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_UPDATEDATASTORERESPONSE.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_UPDATEDATASTORESTATUSREQUEST.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_UPDATEDATASTORESTATUSRESPONSE.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_DELETEDATASTOREREQUEST.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_DELETEDATASTORERESPONSE.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
_WATCHDATASTORESRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_event__pb2._EVENTTYPE
_WATCHDATASTORESRESPONSE.fields_by_name['datastore'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTORE
DESCRIPTOR.message_types_by_name['CreateDatastoreRequest'] = _CREATEDATASTOREREQUEST
DESCRIPTOR.message_types_by_name['CreateDatastoreResponse'] = _CREATEDATASTORERESPONSE
DESCRIPTOR.message_types_by_name['GetDatastoreRequest'] = _GETDATASTOREREQUEST
DESCRIPTOR.message_types_by_name['GetDatastoreResponse'] = _GETDATASTORERESPONSE
DESCRIPTOR.message_types_by_name['ListDatastoresRequest'] = _LISTDATASTORESREQUEST
DESCRIPTOR.message_types_by_name['ListDatastoresResponse'] = _LISTDATASTORESRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDatastoreRequest'] = _UPDATEDATASTOREREQUEST
DESCRIPTOR.message_types_by_name['UpdateDatastoreResponse'] = _UPDATEDATASTORERESPONSE
DESCRIPTOR.message_types_by_name['UpdateDatastoreStatusRequest'] = _UPDATEDATASTORESTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateDatastoreStatusResponse'] = _UPDATEDATASTORESTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteDatastoreRequest'] = _DELETEDATASTOREREQUEST
DESCRIPTOR.message_types_by_name['DeleteDatastoreResponse'] = _DELETEDATASTORERESPONSE
DESCRIPTOR.message_types_by_name['WatchDatastoresRequest'] = _WATCHDATASTORESREQUEST
DESCRIPTOR.message_types_by_name['WatchDatastoresResponse'] = _WATCHDATASTORESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateDatastoreRequest = _reflection.GeneratedProtocolMessageType('CreateDatastoreRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASTOREREQUEST,
  '__module__' : 'grid.v1.datastore_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateDatastoreRequest)
  })
_sym_db.RegisterMessage(CreateDatastoreRequest)

CreateDatastoreResponse = _reflection.GeneratedProtocolMessageType('CreateDatastoreResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASTORERESPONSE,
  '__module__' : 'grid.v1.datastore_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateDatastoreResponse)
  })
_sym_db.RegisterMessage(CreateDatastoreResponse)

GetDatastoreRequest = _reflection.GeneratedProtocolMessageType('GetDatastoreRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASTOREREQUEST,
  '__module__' : 'grid.v1.datastore_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetDatastoreRequest)
  })
_sym_db.RegisterMessage(GetDatastoreRequest)

GetDatastoreResponse = _reflection.GeneratedProtocolMessageType('GetDatastoreResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASTORERESPONSE,
  '__module__' : 'grid.v1.datastore_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetDatastoreResponse)
  })
_sym_db.RegisterMessage(GetDatastoreResponse)

ListDatastoresRequest = _reflection.GeneratedProtocolMessageType('ListDatastoresRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASTORESREQUEST,
  '__module__' : 'grid.v1.datastore_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListDatastoresRequest)
  })
_sym_db.RegisterMessage(ListDatastoresRequest)

ListDatastoresResponse = _reflection.GeneratedProtocolMessageType('ListDatastoresResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASTORESRESPONSE,
  '__module__' : 'grid.v1.datastore_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListDatastoresResponse)
  })
_sym_db.RegisterMessage(ListDatastoresResponse)

UpdateDatastoreRequest = _reflection.GeneratedProtocolMessageType('UpdateDatastoreRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASTOREREQUEST,
  '__module__' : 'grid.v1.datastore_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateDatastoreRequest)
  })
_sym_db.RegisterMessage(UpdateDatastoreRequest)

UpdateDatastoreResponse = _reflection.GeneratedProtocolMessageType('UpdateDatastoreResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASTORERESPONSE,
  '__module__' : 'grid.v1.datastore_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateDatastoreResponse)
  })
_sym_db.RegisterMessage(UpdateDatastoreResponse)

UpdateDatastoreStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateDatastoreStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASTORESTATUSREQUEST,
  '__module__' : 'grid.v1.datastore_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateDatastoreStatusRequest)
  })
_sym_db.RegisterMessage(UpdateDatastoreStatusRequest)

UpdateDatastoreStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateDatastoreStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASTORESTATUSRESPONSE,
  '__module__' : 'grid.v1.datastore_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateDatastoreStatusResponse)
  })
_sym_db.RegisterMessage(UpdateDatastoreStatusResponse)

DeleteDatastoreRequest = _reflection.GeneratedProtocolMessageType('DeleteDatastoreRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASTOREREQUEST,
  '__module__' : 'grid.v1.datastore_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteDatastoreRequest)
  })
_sym_db.RegisterMessage(DeleteDatastoreRequest)

DeleteDatastoreResponse = _reflection.GeneratedProtocolMessageType('DeleteDatastoreResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASTORERESPONSE,
  '__module__' : 'grid.v1.datastore_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteDatastoreResponse)
  })
_sym_db.RegisterMessage(DeleteDatastoreResponse)

WatchDatastoresRequest = _reflection.GeneratedProtocolMessageType('WatchDatastoresRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHDATASTORESREQUEST,
  '__module__' : 'grid.v1.datastore_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchDatastoresRequest)
  })
_sym_db.RegisterMessage(WatchDatastoresRequest)

WatchDatastoresResponse = _reflection.GeneratedProtocolMessageType('WatchDatastoresResponse', (_message.Message,), {
  'DESCRIPTOR' : _WATCHDATASTORESRESPONSE,
  '__module__' : 'grid.v1.datastore_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchDatastoresResponse)
  })
_sym_db.RegisterMessage(WatchDatastoresResponse)


DESCRIPTOR._options = None

_DATASTORESERVICE = _descriptor.ServiceDescriptor(
  name='DatastoreService',
  full_name='grid.v1.DatastoreService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1546,
  serialized_end=2184,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateDatastore',
    full_name='grid.v1.DatastoreService.CreateDatastore',
    index=0,
    containing_service=None,
    input_type=_CREATEDATASTOREREQUEST,
    output_type=_CREATEDATASTORERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDatastore',
    full_name='grid.v1.DatastoreService.GetDatastore',
    index=1,
    containing_service=None,
    input_type=_GETDATASTOREREQUEST,
    output_type=_GETDATASTORERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDatastores',
    full_name='grid.v1.DatastoreService.ListDatastores',
    index=2,
    containing_service=None,
    input_type=_LISTDATASTORESREQUEST,
    output_type=_LISTDATASTORESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDatastore',
    full_name='grid.v1.DatastoreService.UpdateDatastore',
    index=3,
    containing_service=None,
    input_type=_UPDATEDATASTOREREQUEST,
    output_type=_UPDATEDATASTORERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDatastoreStatus',
    full_name='grid.v1.DatastoreService.UpdateDatastoreStatus',
    index=4,
    containing_service=None,
    input_type=_UPDATEDATASTORESTATUSREQUEST,
    output_type=_UPDATEDATASTORESTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDatastore',
    full_name='grid.v1.DatastoreService.DeleteDatastore',
    index=5,
    containing_service=None,
    input_type=_DELETEDATASTOREREQUEST,
    output_type=_DELETEDATASTORERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchDatastores',
    full_name='grid.v1.DatastoreService.WatchDatastores',
    index=6,
    containing_service=None,
    input_type=_WATCHDATASTORESREQUEST,
    output_type=_WATCHDATASTORESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATASTORESERVICE)

DESCRIPTOR.services_by_name['DatastoreService'] = _DATASTORESERVICE

# @@protoc_insertion_point(module_scope)
