# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/whoami.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grid.protos.grid.v1 import user_pb2 as grid_dot_v1_dot_user__pb2
from grid.protos.grid.v1 import cluster_pb2 as grid_dot_v1_dot_cluster__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/whoami.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14grid/v1/whoami.proto\x12\x07grid.v1\x1a\x12grid/v1/user.proto\x1a\x15grid/v1/cluster.proto\"\x0f\n\rWhoAmIRequest\"\x8a\x01\n\x0eWhoAmIResponse\x12#\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserH\x00R\x04user\x12,\n\x07\x63luster\x18\x02 \x01(\x0b\x32\x10.grid.v1.ClusterH\x00R\x07\x63luster\x12\x1c\n\x08internal\x18\x03 \x01(\tH\x00R\x08internalB\x07\n\x05\x61\x63tor2R\n\x15\x41uthenticationService\x12\x39\n\x06WhoAmI\x12\x16.grid.v1.WhoAmIRequest\x1a\x17.grid.v1.WhoAmIResponseB2Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[grid_dot_v1_dot_user__pb2.DESCRIPTOR,grid_dot_v1_dot_cluster__pb2.DESCRIPTOR,])




_WHOAMIREQUEST = _descriptor.Descriptor(
  name='WhoAmIRequest',
  full_name='grid.v1.WhoAmIRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=91,
)


_WHOAMIRESPONSE = _descriptor.Descriptor(
  name='WhoAmIResponse',
  full_name='grid.v1.WhoAmIResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='grid.v1.WhoAmIResponse.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='user', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='grid.v1.WhoAmIResponse.cluster', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='cluster', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal', full_name='grid.v1.WhoAmIResponse.internal', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='internal', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='actor', full_name='grid.v1.WhoAmIResponse.actor',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=94,
  serialized_end=232,
)

_WHOAMIRESPONSE.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_WHOAMIRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_WHOAMIRESPONSE.oneofs_by_name['actor'].fields.append(
  _WHOAMIRESPONSE.fields_by_name['user'])
_WHOAMIRESPONSE.fields_by_name['user'].containing_oneof = _WHOAMIRESPONSE.oneofs_by_name['actor']
_WHOAMIRESPONSE.oneofs_by_name['actor'].fields.append(
  _WHOAMIRESPONSE.fields_by_name['cluster'])
_WHOAMIRESPONSE.fields_by_name['cluster'].containing_oneof = _WHOAMIRESPONSE.oneofs_by_name['actor']
_WHOAMIRESPONSE.oneofs_by_name['actor'].fields.append(
  _WHOAMIRESPONSE.fields_by_name['internal'])
_WHOAMIRESPONSE.fields_by_name['internal'].containing_oneof = _WHOAMIRESPONSE.oneofs_by_name['actor']
DESCRIPTOR.message_types_by_name['WhoAmIRequest'] = _WHOAMIREQUEST
DESCRIPTOR.message_types_by_name['WhoAmIResponse'] = _WHOAMIRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WhoAmIRequest = _reflection.GeneratedProtocolMessageType('WhoAmIRequest', (_message.Message,), {
  'DESCRIPTOR' : _WHOAMIREQUEST,
  '__module__' : 'grid.v1.whoami_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WhoAmIRequest)
  })
_sym_db.RegisterMessage(WhoAmIRequest)

WhoAmIResponse = _reflection.GeneratedProtocolMessageType('WhoAmIResponse', (_message.Message,), {
  'DESCRIPTOR' : _WHOAMIRESPONSE,
  '__module__' : 'grid.v1.whoami_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WhoAmIResponse)
  })
_sym_db.RegisterMessage(WhoAmIResponse)


DESCRIPTOR._options = None

_AUTHENTICATIONSERVICE = _descriptor.ServiceDescriptor(
  name='AuthenticationService',
  full_name='grid.v1.AuthenticationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=234,
  serialized_end=316,
  methods=[
  _descriptor.MethodDescriptor(
    name='WhoAmI',
    full_name='grid.v1.AuthenticationService.WhoAmI',
    index=0,
    containing_service=None,
    input_type=_WHOAMIREQUEST,
    output_type=_WHOAMIRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTHENTICATIONSERVICE)

DESCRIPTOR.services_by_name['AuthenticationService'] = _AUTHENTICATIONSERVICE

# @@protoc_insertion_point(module_scope)
