# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/auth_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/auth_service.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x1agrid/v1/auth_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\"_\n\x0cLoginRequest\x12\x1a\n\x08username\x18\x01 \x01(\tR\x08username\x12\x17\n\x07\x61pi_key\x18\x02 \x01(\tR\x06\x61piKey\x12\x1a\n\x08\x64uration\x18\x03 \x01(\x03R\x08\x64uration\"%\n\rLoginResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\",\n\x0eRefreshRequest\x12\x1a\n\x08\x64uration\x18\x01 \x01(\x03R\x08\x64uration\"\'\n\x0fRefreshResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\"\x0f\n\rLogoutRequest\"\x10\n\x0eLogoutResponse2\x92\x02\n\x0b\x41uthService\x12Q\n\x05Login\x12\x15.grid.v1.LoginRequest\x1a\x16.grid.v1.LoginResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/auth/login:\x01*\x12Y\n\x07Refresh\x12\x17.grid.v1.RefreshRequest\x1a\x18.grid.v1.RefreshResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/auth/refresh:\x01*\x12U\n\x06Logout\x12\x16.grid.v1.LogoutRequest\x1a\x17.grid.v1.LogoutResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/auth/logout:\x01*B2Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
    ]
)

_LOGINREQUEST = _descriptor.Descriptor(
    name='LoginRequest',
    full_name='grid.v1.LoginRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='username',
            full_name='grid.v1.LoginRequest.username',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='username',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='api_key',
            full_name='grid.v1.LoginRequest.api_key',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='apiKey',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='duration',
            full_name='grid.v1.LoginRequest.duration',
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='duration',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=69,
    serialized_end=164,
)

_LOGINRESPONSE = _descriptor.Descriptor(
    name='LoginResponse',
    full_name='grid.v1.LoginResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='token',
            full_name='grid.v1.LoginResponse.token',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='token',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=166,
    serialized_end=203,
)

_REFRESHREQUEST = _descriptor.Descriptor(
    name='RefreshRequest',
    full_name='grid.v1.RefreshRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='duration',
            full_name='grid.v1.RefreshRequest.duration',
            index=0,
            number=1,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='duration',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=205,
    serialized_end=249,
)

_REFRESHRESPONSE = _descriptor.Descriptor(
    name='RefreshResponse',
    full_name='grid.v1.RefreshResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='token',
            full_name='grid.v1.RefreshResponse.token',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='token',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=251,
    serialized_end=290,
)

_LOGOUTREQUEST = _descriptor.Descriptor(
    name='LogoutRequest',
    full_name='grid.v1.LogoutRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=292,
    serialized_end=307,
)

_LOGOUTRESPONSE = _descriptor.Descriptor(
    name='LogoutResponse',
    full_name='grid.v1.LogoutResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=309,
    serialized_end=325,
)

DESCRIPTOR.message_types_by_name['LoginRequest'] = _LOGINREQUEST
DESCRIPTOR.message_types_by_name['LoginResponse'] = _LOGINRESPONSE
DESCRIPTOR.message_types_by_name['RefreshRequest'] = _REFRESHREQUEST
DESCRIPTOR.message_types_by_name['RefreshResponse'] = _REFRESHRESPONSE
DESCRIPTOR.message_types_by_name['LogoutRequest'] = _LOGOUTREQUEST
DESCRIPTOR.message_types_by_name['LogoutResponse'] = _LOGOUTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LoginRequest = _reflection.GeneratedProtocolMessageType(
    'LoginRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LOGINREQUEST,
        '__module__': 'grid.v1.auth_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.LoginRequest)
    }
)
_sym_db.RegisterMessage(LoginRequest)

LoginResponse = _reflection.GeneratedProtocolMessageType(
    'LoginResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LOGINRESPONSE,
        '__module__': 'grid.v1.auth_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.LoginResponse)
    }
)
_sym_db.RegisterMessage(LoginResponse)

RefreshRequest = _reflection.GeneratedProtocolMessageType(
    'RefreshRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _REFRESHREQUEST,
        '__module__': 'grid.v1.auth_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.RefreshRequest)
    }
)
_sym_db.RegisterMessage(RefreshRequest)

RefreshResponse = _reflection.GeneratedProtocolMessageType(
    'RefreshResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _REFRESHRESPONSE,
        '__module__': 'grid.v1.auth_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.RefreshResponse)
    }
)
_sym_db.RegisterMessage(RefreshResponse)

LogoutRequest = _reflection.GeneratedProtocolMessageType(
    'LogoutRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LOGOUTREQUEST,
        '__module__': 'grid.v1.auth_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.LogoutRequest)
    }
)
_sym_db.RegisterMessage(LogoutRequest)

LogoutResponse = _reflection.GeneratedProtocolMessageType(
    'LogoutResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _LOGOUTRESPONSE,
        '__module__': 'grid.v1.auth_service_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.LogoutResponse)
    }
)
_sym_db.RegisterMessage(LogoutResponse)

DESCRIPTOR._options = None

_AUTHSERVICE = _descriptor.ServiceDescriptor(
    name='AuthService',
    full_name='grid.v1.AuthService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=328,
    serialized_end=602,
    methods=[
        _descriptor.MethodDescriptor(
            name='Login',
            full_name='grid.v1.AuthService.Login',
            index=0,
            containing_service=None,
            input_type=_LOGINREQUEST,
            output_type=_LOGINRESPONSE,
            serialized_options=b'\202\323\344\223\002\023\"\016/v1/auth/login:\001*',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='Refresh',
            full_name='grid.v1.AuthService.Refresh',
            index=1,
            containing_service=None,
            input_type=_REFRESHREQUEST,
            output_type=_REFRESHRESPONSE,
            serialized_options=b'\202\323\344\223\002\025\"\020/v1/auth/refresh:\001*',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name='Logout',
            full_name='grid.v1.AuthService.Logout',
            index=2,
            containing_service=None,
            input_type=_LOGOUTREQUEST,
            output_type=_LOGOUTRESPONSE,
            serialized_options=b'\202\323\344\223\002\024\"\017/v1/auth/logout:\001*',
            create_key=_descriptor._internal_create_key,
        ),
    ]
)
_sym_db.RegisterServiceDescriptor(_AUTHSERVICE)

DESCRIPTOR.services_by_name['AuthService'] = _AUTHSERVICE

# @@protoc_insertion_point(module_scope)
